@@ -1,14 +1,14 @@
 R_w_ma <-
 function(theta,nstart,nlen){
 
-    T=nrow(theta)
+    T_t=nrow(theta)
     q=ncol(theta)
     q=q-1  
  
     B=matrix(0,nlen,nlen+q)
     n=nstart
     for (j in 1:nlen)
-        {time_index=matlab::mod(n-1,T)+1
+        {time_index=matlab::mod(n-1,T_t)+1
          B[j,j:(j+q)]=matlab::fliplr(theta[time_index,])
          n=n+1}
      r=B%*%t(B)
