@@ -1,3 +1,8 @@
+#' just supporting function
+#'
+#' @importFrom matlab flipud
+#' @importFrom signal conv
+
 acfpacf.acf <-
 function(x,normflg){
 
@@ -6,12 +11,12 @@ function(x,normflg){
    nc=ncol(y)
   if (nc > nr)
    {stop(" 'x' must be a column vector")}
-  
-    f=matlab::flipud(x)        
-    r=signal::conv(f,x)
+
+    f=flipud(x)
+    r=conv(f,x)
     r=r[nr:length(r)]
 
-   if (normflg==0) 
+   if (normflg==0)
     { r=r/nr
       } else {
         if (normflg==1)
@@ -19,11 +24,11 @@ function(x,normflg){
          r=r/r[1]
         }else {
           if(normflg==2)
-            { den=t(seq(nr,1,-1))   
+            { den=t(seq(nr,1,-1))
                r=r/den
                r=t(r)
-             } else { 
-               den=t(seq(nr,1,-1)) 
+             } else {
+               den=t(seq(nr,1,-1))
                r=r/den
                r=r/r[1]
                r=t(r)
